import { MigrationInterface, QueryRunner, Table } from 'typeorm';
import { CreatedAt, ID, NOT_NULL, TINYINT, UpdatedAt, VARCHAR } from './utils';

export class CreateTableTranslateDevice1739177747810
  implements MigrationInterface
{
  TABLE_NAME = 'translatedevice';
  public async up(queryRunner: QueryRunner): Promise<void> {
    const exist = await queryRunner.hasTable(this.TABLE_NAME);
    if (exist) return;
    await queryRunner.createTable(
      new Table({
        name: this.TABLE_NAME,
        columns: [
          ID,
          {
            name: 'sn',
            ...VARCHAR,
            length: '255',
            comment: '设备序列号',
            ...NOT_NULL,
          },
          {
            name: 'name',
            ...VARCHAR,
            length: '255',
            comment: '设备名称',
            ...NOT_NULL,
          },
          {
            name: 'type',
            ...VARCHAR,
            length: '255',
            comment: '设备类型',
            ...NOT_NULL,
          },
          {
            name: 'status',
            ...TINYINT,
            comment: '状态：0禁用、1启用',
            default: '1',
            ...NOT_NULL,
          },
          {
            name: 'deleted',
            ...TINYINT,
            comment: '0未删除、1已删除',
            default: '0',
            ...NOT_NULL,
          },
          CreatedAt,
          UpdatedAt,
        ],
      }),
    );
  }

  public async down(queryRunner: QueryRunner): Promise<void> {}
}
