import _ from 'lodash';
import { DataSource } from 'typeorm';
import 'dotenv/config'; // 加载 .env 文件

// 递归合并
// 优先级 env > config.{NODE_ENV}.yaml > 默认值

const ENV = process.env;

const database: any = {
  type: ENV.APP_DATABASE_TYPE,
  url: ENV.APP_DATABASE_URL,
};
const migrationsDir = process.env.MIGRATIONS_DIR || 'migrations';
// The following line works for me. Try this if the above throws an error.
// const migrationsDir = process.env.MIGRATIONS_DIR || 'migrations-build';
// According to the TypeORM doc at https://github.com/typeorm/typeorm/blob/master/docs/migrations.md#running-and-reverting-migrations
// The `migration:run` and `migration:revert` commands only work on `.js` files.
// TypeScript files need to be compiled before running the commands.

export const dataSource = new DataSource({
  ...database,
  synchronize: false,
  logging: 'error',
  migrations: [__dirname + `/${migrationsDir}/*{.ts,.js}`],
});
