import {
  MiddlewareConsumer,
  Module,
  NestModule,
  RequestMethod,
} from '@nestjs/common';
import { config } from './config';
import { TypeOrmModule } from '@nestjs/typeorm';
import { SystemController } from './controller/system.controller';
import { UserModule } from './controller/user/user.module';
import { AuthModule } from './controller/auth/auth.module';
import { RedisModule } from '@nestjs-modules/ioredis';
import { TranslateModule } from './controller/translate/translate.module';
import { DeviceModule } from './controller/device/device.module';
import { JwtModule } from '@nestjs/jwt';

@Module({
  imports: [
    TypeOrmModule.forRoot({
      ...config.database,
      name: 'default',
      entities: [__dirname + '/**/*.entity{.ts,.js}'],
      keepConnectionAlive: true,
      synchronize: false,
      maxQueryExecutionTime: 200,
      logging: [config.database.logging],
    }),
    RedisModule.forRoot({
      type: 'single',
      url: config.cache.redis.url,
    }),
    JwtModule.register({
      global: true,
      secret: config.jwt.secret,
      signOptions: { expiresIn: config.jwt.expiresIn },
    }),
    UserModule,
    AuthModule,
    TranslateModule,
    DeviceModule,
  ],
  controllers: [SystemController],
})
export class AppModule implements NestModule {
  configure(consumer: MiddlewareConsumer) {
    consumer.apply().forRoutes({ path: '*', method: RequestMethod.ALL });
  }
}
