import { ApiProperty } from '@nestjs/swagger';
import {
  IsString,
  IsNotEmpty,
  IsPhoneNumber,
  IsNumber,
  Matches,
} from 'class-validator';

export class RegisterDto {
  @ApiProperty({
    description: '用户的手机号码',
    type: 'string',
    example: '13800138000',
  })
  @IsNotEmpty()
  @IsString()
  @IsPhoneNumber('CN')
  phone: string;

  @ApiProperty({
    description: '短信验证码',
    type: 'number',
    example: 1234,
  })
  @IsNotEmpty()
  @IsNumber()
  code: number;

  @ApiProperty({
    description: '用户的密码',
    type: 'string',
    example: '1234test',
  })
  @IsNotEmpty()
  @IsString()
  @Matches(/^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d]{6,}$/, {
    message: '密码必须包含至少6个字符，包括字母和数字',
  })
  password: string;
}
