import {
  Controller,
  Post,
  Body,
  Param,
  Delete,
  Get,
  UseInterceptors,
  UseFilters,
} from '@nestjs/common';
import { DeviceService } from './device.service';
import { CreateDeviceDto } from './dto/create-device.dto';
import { DeleteDeviceDto } from './dto/delete-device.dto';
import { BadRequestError } from '@/common/exception/badRequest/BadRequestError';
import { JwtService } from '@nestjs/jwt';
import { UnauthorizedError } from '@/common/exception/unauthorized/UnauthorizedError';
import { ApiResponseInterceptor } from '@/common/interceptor/api.response.interceptor';
import { ApiExceptionsFilter } from '@/common/filter/api.exception.filter';

@Controller('')
@UseInterceptors(ApiResponseInterceptor)
@UseFilters(ApiExceptionsFilter)
export class DeviceController {
  constructor(
    private readonly deviceService: DeviceService,
    private readonly jwtService: JwtService,
  ) {}

  @Post('/device/register')
  async create(@Body() dto: CreateDeviceDto) {
    const exist = await this.deviceService.findBySn(dto.sn);

    if (exist) {
      return BadRequestError.default('device is exist');
    }

    return await this.deviceService.create(dto);
  }

  @Get('/device/getToken')
  async getToken(@Param('sn') sn: string) {
    const exist = await this.deviceService.findBySn(sn);

    if (exist?.deleted === true) {
      throw UnauthorizedError.default();
    }

    const payload = { sub: sn, username: exist.name };

    return await this.jwtService.signAsync(payload);
  }

  @Delete('/device/delete')
  async remove(@Body() dto: DeleteDeviceDto) {
    return this.deviceService.remove(dto.sn);
  }
}
